aboutsummaryrefslogtreecommitdiff
path: root/src/common/dwarf/functioninfo.h
diff options
context:
space:
mode:
authorjimblandy <jimblandy@4c0a9323-5329-0410-9bdc-e9ce6186880e>2010-01-22 23:30:36 +0000
committerjimblandy <jimblandy@4c0a9323-5329-0410-9bdc-e9ce6186880e>2010-01-22 23:30:36 +0000
commit8bfcc2683f6cb4345b56c898eabe45efeb77dc3e (patch)
tree15c8d5ef0f7f5ab569fad2a207862b2ab9f1d4c9 /src/common/dwarf/functioninfo.h
parentBreakpad DWARF Reader: Also look for DWARF in sections with the proper names. (diff)
downloadbreakpad-8bfcc2683f6cb4345b56c898eabe45efeb77dc3e.tar.xz
Breakpad DWARF Reader: Change LineInfoHandler::AddLine to provide the line's length.
Breakpad's DWARF line number info parser provides a code address, file, and line number for each code/source pairing, but doesn't provide the length of the machine code. This makes that change, as discussed in the following thread: http://groups.google.com/group/google-breakpad-dev/browse_thread/thread/ed8d2fde79319368p This patch also makes the corresponding changes to the functioninfo.cc module, used by the Mac dumper. This patch has no effect on the Mac dumper's output. a=jimblandy, r=ccoutant git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@494 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/common/dwarf/functioninfo.h')
-rw-r--r--src/common/dwarf/functioninfo.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/common/dwarf/functioninfo.h b/src/common/dwarf/functioninfo.h
index 3351c67c..d941ec0d 100644
--- a/src/common/dwarf/functioninfo.h
+++ b/src/common/dwarf/functioninfo.h
@@ -1,4 +1,4 @@
-// Copyright 2006 Google Inc. All Rights Reserved.
+// Copyright 2010 Google Inc. All Rights Reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
@@ -92,13 +92,13 @@ class CULineInfoHandler: public LineInfoHandler {
// Called when the line info reader has a new line, address pair
- // ready for us. ADDRESS is the address of the code, FILE_NUM is
- // the file number containing the code, LINE_NUM is the line number
- // in that file for the code, and COLUMN_NUM is the column number
- // the code starts at, if we know it (0 otherwise).
- virtual void AddLine(uint64 address, uint32 file_num, uint32 line_num,
- uint32 column_num);
-
+ // ready for us. ADDRESS is the address of the code, LENGTH is the
+ // length of its machine code in bytes, FILE_NUM is the file number
+ // containing the code, LINE_NUM is the line number in that file for
+ // the code, and COLUMN_NUM is the column number the code starts at,
+ // if we know it (0 otherwise).
+ virtual void AddLine(uint64 address, uint64 length,
+ uint32 file_num, uint32 line_num, uint32 column_num);
private:
LineMap* linemap_;